@@ -1,7 +1,8 @@
 
 import wx
-import logging.config
 from src.view.sql_editor_view import DatabaseMainFrame
+from src.view.EditorSplash import MyApp
+import logging.config
 from src.view.constants import LOG_SETTINGS
 
 logger = logging.getLogger('extensive')
@@ -12,11 +13,14 @@ logging.config.dictConfig(LOG_SETTINGS)
 
 
 def main():
-    app = wx.App()
-    frame = DatabaseMainFrame(None)
-    frame.Show()
+    app = MyApp(False)
     app.MainLoop()
 
+#     app = wx.App()
+#     frame = DatabaseMainFrame(None)
+#     frame.Show()
+#     app.MainLoop()
+
 
 
 
