@@ -10,7 +10,6 @@ from os.path import expanduser
 import sys
 import logging
 from datetime import date, datetime
-from sqlalchemy.sql.expression import false
 
 logger = logging.getLogger('extensive')
 
@@ -344,30 +343,44 @@ class SQLUtils():
         '''
         This is to define new table name .
         '''
-        
-#         while
-        tableName=None
+        tableName = None
         try:
             manageSqliteDatabase = ManageSqliteDatabase(connectionName=connectionName, databaseAbsolutePath=self.getDbFilePath(connectionName))
             sqlText = "select tbl_name from sqlite_master order by tbl_name;"
             tbl_name_list = manageSqliteDatabase.executeSelectQuery(sqlText)
             logger.debug(tbl_name_list)
             
-            tablePresent=False
-            i=1
+            tablePresent = False
+            i = 1
             while not tablePresent:
-                tableName='Table {}'.format(i)
+                tableName = 'Table_{}'.format(i)
                 if tuple([tableName]) in tbl_name_list:
-                    logger.info(tableName+' already present')
-                    i +=1
+                    logger.info(tableName + ' already present')
+                    i += 1
                 else:
-                    tablePresent=True
+                    tablePresent = True
              
         except Exception as e:
             logger.error(e, exc_info=True)
         
         return tableName
     
+    def importingData(self, connectionName=None, sqlList=None):
+        logger.info('importingData to {}'.format(connectionName))
+        count = 0
+        try:
+            manageSqliteDatabase = ManageSqliteDatabase(connectionName=connectionName, databaseAbsolutePath=self.getDbFilePath(connectionName))
+            for sql in sqlList:
+                manageSqliteDatabase.executeText(sql)
+                count += 1
+        except Exception as e:
+            count -= 1
+            logger.error(e, exc_info=True)      
+        importStatus = "Total rows {} / {} inserted.".format(count, len(sqlList) - 1)
+        logger.info("Total rows {} / {} inserted.".format(count, len(sqlList) - 1))
+        return importStatus
+
+
 class ManageSqliteDatabase():
 
     def __init__(self, connectionName=None, databaseAbsolutePath=None):
@@ -396,27 +409,20 @@ class ManageSqliteDatabase():
         
     def getObject(self):
         '''
-        Method returns all database object [ table, view, index] from the given sqlite database path
+        @return: Method returns all database object [ table, view, index] from the given sqlite database path
         '''
-    
         con = None
         
         try:
-#             self.connection = sqlite3.connect('_opal.sqlite')
-            
             cur = self.conn.cursor()    
             cur.execute('SELECT SQLITE_VERSION()')
-            
             data = cur.fetchone()
-            
             logger.debug("SQLite version: %s" % data)   
             cur.execute("select tbl_name from sqlite_master where type='table';")
             types = cur.execute("select distinct type from sqlite_master;").fetchall()
             databaseList = list()
             dbObjects = list()
-#             logger.debug types
             for t in types:
-#                 logger.debug t[0], type(t)
                 tObjectArrayList = list()
                 query = "select tbl_name from sqlite_master where type='{}' order by tbl_name;".format(t[0])
                 logger.debug(query)
@@ -424,30 +430,20 @@ class ManageSqliteDatabase():
                 tableColumnList = list()
                 for tObj in tObjectList:
                     if t[0] == 'table' or t[0] == 'index':
-#                         tableColumnsOrIndexesSql = "PRAGMA " + t[0] + "_info(%s);" % tObj[0]
                         tableColumnsOrIndexesSql = "PRAGMA {}_info('{}');".format(t[0], tObj[0])
-                        
-#                         logger.debug(tableColumnsOrIndexesSql)
                         tableColumnsOrIndexesList = cur.execute(tableColumnsOrIndexesSql).fetchall()
-#                         logger.debug objChildList
                         tableColumnsOrIndexes = list()
                         for objChild in tableColumnsOrIndexesList:
                             tableColumnsOrIndexes.append(objChild)
-#                             print objChild
                         tableColumnList.append({tObj[0]: tableColumnsOrIndexes})
                     if t[0] == 'view':
                         tableColumnList.append({tObj[0]: []})
                         logger.debug('view')
-
                 dbObjects.append({t[0]: tableColumnList})
-#             logger.debug(dbObjects)
-
         except sqlite3.Error as e:
             logger.error(e, exc_info=True)
             sys.exit(1)
-            
         finally:
-            
             if self.conn:
                 self.conn.close()
         databaseList.append(self.connectionName)
@@ -456,27 +452,22 @@ class ManageSqliteDatabase():
 
     def executeText(self, text=None):
         ''' This method takes input text to execute in database.
-        returns output as dict
+        @return script output as dict
         '''
         sqlOutput = dict()
         try:
             with self.conn:    
                 cur = self.conn.cursor() 
-#                 logger.debug('before')
                 listOfSqls = text.strip().lower().split(';')
                 if len(listOfSqls) > 1 and not text.strip().lower().startswith('select'):
                     cur.executescript(text)
-                elif text.strip().lower().startswith('update'):
+                elif text.strip().lower().startswith(('update','drop','alter')):
                     cur.execute(text)
                 else:
                     rows = cur.execute(text).fetchall()
-#                     logger.debug(rows)
-#                     logger.debug(cur.description) 
-    #                 logger.debug(rows)
                     if cur.description:
                         headerList = list()
                         for idx, desc in enumerate(cur.description):
-        #                     logger.debug(idx, desc)
                             headerList.append(desc[0])
                         sqlOutput[0] = tuple(headerList)
                         for idx, item in enumerate(rows):
@@ -485,12 +476,10 @@ class ManageSqliteDatabase():
             logger.error(e, exc_info=True)
             raise e
             self.conn.rollback()
-#             raise e
-#         logger.debug(sqlOutput)
-        return sqlOutput
+        return sqlOutput 
     
     def executeSelectQuery(self, text=None):
-        rows=None
+        rows = None
         with self.conn:    
                 cur = self.conn.cursor() 
                 rows = cur.execute(text).fetchall()
@@ -524,26 +513,23 @@ class ManageSqliteDatabase():
             self.conn.rollback()
             raise e
     
-    def sqlite_select(self, table):
+    def sqlite_select(self, tableName=None):
         
         returnRows = list()
-        with self.conn:    
-            
-            cur = self.conn.cursor() 
-#             logger.debug('before')
-            cur.execute("SELECT * FROM {}".format(table))
-        
-            rows = cur.fetchall()
-            
-            for row in rows:
-                returnRows.append(row)
+        if tableName:
+            with self.conn:    
+                cur = self.conn.cursor() 
+                cur.execute("SELECT * FROM {}".format(tableName))
+                rows = cur.fetchall()
+                for row in rows:
+                    returnRows.append(row)
         return returnRows
     
     def getColumn(self, tableName=None):
         try:
             with self.conn:    
                 cur = self.conn.cursor() 
-                sql = "SELECT name, sql FROM sqlite_master WHERE type='table' AND name = '" + tableName + "';"
+                sql = "SELECT name, sql FROM sqlite_master WHERE type='table' AND name = '{}';".format(tableName)
                 rows = cur.execute(sql).fetchall()
                 tableCreateStmt = rows[0][1]
                 match = re.findall(r'[^[]*\[([^]]*)\]', tableCreateStmt)
@@ -562,8 +548,8 @@ class ManageSqliteDatabase():
     
 if __name__ == "__main__":
     logger.debug('hi')
-    tableName=SQLUtils().definingTableName(connectionName='picture')
-    print(tableName)
+#     tableName = SQLUtils().definingTableName(connectionName='picture')
+#     print(tableName)
     
 #########################################################################################
 #     sqlExecuter = SQLExecuter(database='_opal.sqlite')
@@ -593,4 +579,9 @@ if __name__ == "__main__":
 ##########################################################################################
             
 #     logger.debug(dbList)
-#     ManageSqliteDatabase(connectionName="1", databaseAbsolutePath=r"_opal_1.sqlite")
+    connectionName="emp"
+    sqlExecuter=SQLExecuter()
+    databaseAbsolutePath=sqlExecuter.getDbFilePath(connectionName=connectionName)
+    db=ManageSqliteDatabase(connectionName=connectionName ,databaseAbsolutePath=databaseAbsolutePath)
+    result=db.sqlite_select(tableName="sqlite_master")
+    logger.debug(result)
