@@ -9,7 +9,8 @@ import os
 from wx import TreeCtrl
 from wx.lib.mixins.treemixin import ExpansionState
 from src.view.constants import ID_newWorksheet, ID_CONNECT_DB, ID_deleteWithDatabase, \
-    ID_DISCONNECT_DB, ID_ROOT_NEW_CONNECTION, ID_ROOT_REFERESH, keyMap
+    ID_DISCONNECT_DB, ID_ROOT_NEW_CONNECTION, ID_ROOT_REFERESH, keyMap, \
+    ID_Import
 # from src.view.table.CreateTable import CreateTableFrame
 from src.sqlite_executer.ConnectExecuteSqlite import SQLExecuter, \
     ManageSqliteDatabase, SQLUtils
@@ -18,6 +19,9 @@ from src.view.schema.CreateSchemaViewer import CreateErDiagramFrame
 import logging
 from src.view.table.CreateTable import CreatingTableFrame
 from src.view.util.FileOperationsUtil import FileOperations
+from src.view.importing.importCsvExcel import ImportingCsvExcelFrame
+import ntpath
+import datetime
 
 logger = logging.getLogger('extensive')
 
@@ -27,7 +31,7 @@ class CreatingTreePanel(wx.Panel):
     def __init__(self, parent=None, *args, **kw):
         wx.Panel.__init__(self, parent, id=-1)
         self.parent = parent
-        
+        self.fileOperations = FileOperations()
         self.connDict = dict()
         vBox = wx.BoxSizer(wx.VERTICAL)
         ####################################################################
@@ -44,11 +48,14 @@ class CreatingTreePanel(wx.Panel):
         self.filter.Bind(wx.EVT_TEXT_ENTER, self.OnSearch)
         self.recreateTree()
         
+        # add drop target
+        self.SetDropTarget(MyFileDropTarget(self))
 #         self.tree.SetExpansionState(self.expansionState)
         self.tree.Bind(wx.EVT_TREE_ITEM_EXPANDED, self.OnItemExpanded)
         self.tree.Bind(wx.EVT_TREE_ITEM_COLLAPSED, self.OnItemCollapsed)
         self.tree.Bind(wx.EVT_TREE_SEL_CHANGED, self.OnSelChanged)
         self.tree.Bind(wx.EVT_LEFT_DOWN, self.OnTreeLeftDown)
+        self.tree.Bind(wx.EVT_LEFT_DCLICK, self.OnTreeDoubleclick)
         self.tree.Bind(wx.EVT_TREE_ITEM_ACTIVATED, self.onTreeItemActivated)
         self.tree.Bind(wx.EVT_TREE_KEY_DOWN, self.onTreeKeyDown)
         self.tree.Bind(wx.EVT_TREE_BEGIN_DRAG, self.onTreeBeginDrag)
@@ -97,7 +104,7 @@ class CreatingTreePanel(wx.Panel):
                     
         self.createDefaultNode()
                     
-        self.tree.Expand(self.root)
+#         self.tree.Expand(self.root)
         
         self.tree.Thaw()
         self.searchItems = {}
@@ -107,7 +114,8 @@ class CreatingTreePanel(wx.Panel):
         logger.debug("TreePanel.createDefaultNode")
         sqlExecuter = SQLExecuter()
         dbList = sqlExecuter.getListDatabase()
-        
+
+            
         fullSearch = False
         expansionState = self.tree.GetExpansionState()
 
@@ -116,8 +124,7 @@ class CreatingTreePanel(wx.Panel):
         if item:
             prnt = self.tree.GetItemParent(item)
             if prnt:
-                current = (self.tree.GetItemText(item),
-                           self.tree.GetItemText(prnt))
+                current = (self.tree.GetItemText(item), self.tree.GetItemText(prnt))
         self.tree.Freeze()
         self.tree.DeleteAllItems()
         self.root = self.tree.AddRoot("Connections")
@@ -156,13 +163,19 @@ class CreatingTreePanel(wx.Panel):
 #                 image=16
             
             # Appending connections
-            self.addNode(targetNode=self.root, nodeLabel=db[1], pydata=data, image=image)
-
+            item=self.addNode(targetNode=self.root, nodeLabel=db[1], pydata=data, image=image)
+#             self.connDict[db[1]]['itemId']=item
+            if db[1] in self.connDict.keys():
+                self.getNodeOnOpenConnection(selectedItemId=item)
+#         for key, value in self.connDict.items():
+#             if value['isConnected']:
+#                 logger.debug("{}:{}".format(key, value))
+        self.tree.Expand(self.root)
         if firstChild:
             self.tree.Expand(firstChild)
-        if filter:
-            self.tree.ExpandAll()
-        elif expansionState:
+#         if filter:
+#             self.tree.ExpandAll()
+        if expansionState:
             self.tree.SetExpansionState(expansionState)
         if selectItem:
             self.skipLoad = True
@@ -179,7 +192,7 @@ class CreatingTreePanel(wx.Panel):
     #---------------------------------------------
     def OnItemExpanded(self, event):
         item = event.GetItem()
-#         logger.debug("OnItemExpanded: %s" % self.tree.GetItemText(item))
+        logger.debug("OnItemExpanded: %s" % self.tree.GetItemText(item))
         event.Skip()
 
     #---------------------------------------------
@@ -209,6 +222,8 @@ class CreatingTreePanel(wx.Panel):
             self.onTreeCopy(event)
         elif keypress == 'WXK_F2':
             self.onF2KeyPress(event)
+        elif keypress == 'WXK_DELETE':
+            self.onDeleteKeyPress(event)
         event.Skip()
         
     def GetKeyPress(self, evt):
@@ -229,11 +244,26 @@ class CreatingTreePanel(wx.Panel):
                 keyname = "(%s)unknown" % keycode
         return modifiers + keyname
 
+    #----------------------------------------------------------------------
+    def onDeleteKeyPress(self, event):
+        try:
+            logger.debug(self.tree.GetItemData(self.tree.GetSelection()))
+            depth = self.tree.GetItemData(self.tree.GetSelection())['depth']
+            if depth == 1:
+                self.onDeleteConnection(event)
+            elif depth == 3:
+                logger.debug("TODO delete table")
+                self.onDeleteTable(event)
+            elif depth == 5:
+                logger.debug("TODO delete column")
+        except Exception as e:
+            logger.error(e, exc_info=True)
+
     #----------------------------------------------------------------------
     def onF2KeyPress(self, event):
         try:
-            logger.debug(self.tree.GetItemData(self.tree.GetSelection()).Data)
-            depth = self.tree.GetItemData(self.tree.GetSelection()).Data['depth']
+            logger.debug(self.tree.GetItemData(self.tree.GetSelection()))
+            depth = self.tree.GetItemData(self.tree.GetSelection())['depth']
             if depth == 3:
                 self.onRenameTable(event)
             elif depth == 5:
@@ -241,8 +271,7 @@ class CreatingTreePanel(wx.Panel):
                 
         except Exception as e:
             logger.error(e, exc_info=True)
-        pass
-
+    
     def onTreeCopy(self, event):
         """"""
         self.dataObj = wx.TextDataObject()
@@ -255,11 +284,30 @@ class CreatingTreePanel(wx.Panel):
         except TypeError:
             wx.MessageBox("Unable to open the clipboard", "Error")
         
+    def OnTreeDoubleclick(self, event):
+        logger.info("OnTreeDoubleclick")
+        pt = event.GetPosition();
+        item, flags = self.tree.HitTest(pt)
+        data = self.tree.GetItemData(item)
+        rightClickDepth = data['depth']
+        logger.info("Depth: {}".format(data['depth']))
+        if rightClickDepth == 1:
+            self.onConnectDb(event)
+        if rightClickDepth == 3:
+            # Open a new tab in SQL execution Pane. It is for table info.
+            # TODO 
+            sheetName = "tableInfo_{}".format(self.tree.GetItemText(item))
+            self.openWorksheet(sheetName=sheetName)
+        if self.tree.IsExpanded(item):
+            self.tree.Collapse(item)
+        else:
+            self.tree.Expand(item)
+        
     def OnTreeLeftDown(self, event):
         # reset the overview text if the tree item is clicked on again
         pt = event.GetPosition();
         item, flags = self.tree.HitTest(pt)
-        if item == self.tree.GetSelection():
+        if item and item == self.tree.GetSelection():
             logger.debug(self.tree.GetItemText(item) + " Overview")
         event.Skip()
 
@@ -285,18 +333,7 @@ class CreatingTreePanel(wx.Panel):
     #---------------------------------------------
     def OnTreeRightUp(self, event):
         event.Skip
-        path = os.path.abspath(__file__)
-        tail = None
-#         head, tail = os.path.split(path)
-#         print('createAuiManager',head, tail )
-        try:
-            while tail != 'src':
-                path = os.path.abspath(os.path.join(path, '..',))
-                head, tail = os.path.split(path)
-        except Exception as e:
-            logger.error(e, exc_info=True)
-        path = os.path.abspath(os.path.join(path, "images"))
-        
+       
         item = self.tree.item     
         
         if not item:
@@ -311,13 +348,14 @@ class CreatingTreePanel(wx.Panel):
             rootNewConnection = menu.Append(ID_ROOT_NEW_CONNECTION, "New connection ")
             
             refreshBmp = wx.MenuItem(menu, ID_ROOT_REFERESH, "&Refresh")
-            refreshBmp.SetBitmap(wx.Bitmap(os.path.abspath(os.path.join(path, "database_refresh.png"))))
+            refreshBmp.SetBitmap(wx.Bitmap(self.fileOperations.getImageBitmap(imageName="database_refresh.png")))
             rootRefresh = menu.Append(refreshBmp)
             
             self.Bind(wx.EVT_MENU, self.onRootRefresh, rootRefresh)
             self.Bind(wx.EVT_MENU, self.onRootNewConnection, rootNewConnection)
         elif rightClickDepth == 1:
-            if self.tree.GetItemText(self.tree.GetSelection()) in self.connDict:
+            if data['connection_name'] in self.connDict and \
+                self.connDict[data['connection_name']]['isConnected']:
                 item1 = menu.Append(ID_DISCONNECT_DB, "Disconnect")
                 self.Bind(wx.EVT_MENU, self.onDisconnectDb, item1)
             else:
@@ -325,16 +363,20 @@ class CreatingTreePanel(wx.Panel):
                 self.Bind(wx.EVT_MENU, self.onConnectDb, item2)
             
             sqlEditorBmp = wx.MenuItem(menu, ID_newWorksheet, "SQL Editor in new Tab")
-            sqlEditorBmp.SetBitmap(wx.Bitmap(os.path.abspath(os.path.join(path, "script.png"))))
+            sqlEditorBmp.SetBitmap(wx.Bitmap(self.fileOperations.getImageBitmap(imageName="script.png")))
             item3 = menu.Append(sqlEditorBmp)
             
             infoMenuItem = wx.MenuItem(menu, wx.ID_ANY, "Properties")
             infoBmp = wx.ArtProvider.GetBitmap(wx.ART_INFORMATION, wx.ART_MENU, (16, 16)) 
             infoMenuItem.SetBitmap(infoBmp)     
-            item4 = menu.Append(infoMenuItem)      
+            item4 = menu.Append(infoMenuItem)    
+            
+            importBmp = wx.MenuItem(menu, ID_Import, "&Import CSV / Excel")
+            importBmp.SetBitmap(wx.Bitmap(self.fileOperations.getImageBitmap(imageName="import.png")))
+            importMenu = menu.Append(importBmp)  
             
             refreshBmp = wx.MenuItem(menu, wx.ID_REFRESH, "&Refresh")
-            refreshBmp.SetBitmap(wx.Bitmap(os.path.abspath(os.path.join(path, "database_refresh.png"))))
+            refreshBmp.SetBitmap(wx.Bitmap(self.fileOperations.getImageBitmap(imageName="database_refresh.png")))
             item5 = menu.Append(refreshBmp)
             
             item6 = menu.Append(wx.ID_ANY, "Properties")
@@ -348,7 +390,7 @@ class CreatingTreePanel(wx.Panel):
             deleteMenuItem.SetBitmap(delBmp)
             delMenu = menu.Append(deleteMenuItem)
             
-            deleteWithDatabaseMenuItem = wx.MenuItem(menu, ID_deleteWithDatabase, "Delete with database \t Delete")
+            deleteWithDatabaseMenuItem = wx.MenuItem(menu, ID_deleteWithDatabase, "Delete with database \t Shift + Delete")
             delBmp = wx.ArtProvider.GetBitmap(wx.ART_DELETE, wx.ART_MENU, (16, 16))
             deleteWithDatabaseMenuItem.SetBitmap(delBmp)
             deleteWithDatabaseMenu = menu.Append(deleteWithDatabaseMenuItem)
@@ -356,6 +398,7 @@ class CreatingTreePanel(wx.Panel):
             
             self.Bind(wx.EVT_MENU, self.onOpenSqlEditorTab, item3)
             self.Bind(wx.EVT_MENU, self.onProperties, item4)
+            self.Bind(wx.EVT_MENU, self.onImport, importMenu)
             self.Bind(wx.EVT_MENU, self.onRefresh, item5)
             self.Bind(wx.EVT_MENU, self.onEditConnection, item6)
             self.Bind(wx.EVT_MENU, self.onDeleteConnection, delMenu)
@@ -363,7 +406,11 @@ class CreatingTreePanel(wx.Panel):
 
         elif rightClickDepth == 2:
             if 'table' in self.tree.GetItemText(item):
-                newTableItem = menu.Append(wx.ID_ANY, "Create new table")
+                newTableBmp = wx.MenuItem(menu, wx.ID_ANY, "Create new table")
+                newTableBmp.SetBitmap(wx.Bitmap(self.fileOperations.getImageBitmap(imageName="table_add.png")))
+                newTableItem = menu.Append(newTableBmp)                 
+                
+#                 newTableItem = menu.Append(wx.ID_ANY, "Create new table")
                 erDiagramItem = menu.Append(wx.ID_ANY, "Create ER diagram")
                 refreshTableItem = menu.Append(wx.ID_ANY, "Refresh  \tF5")
                 
@@ -383,20 +430,25 @@ class CreatingTreePanel(wx.Panel):
                 self.Bind(wx.EVT_MENU, self.onNewIndex, newIndexItem)
                 
         elif 'Columns' in self.tree.GetItemText(item) :
-            item1 = menu.Append(wx.ID_ANY, "Create new column")
+            newColumnItem = menu.Append(wx.ID_ANY, "Add new column")
+            self.Bind(wx.EVT_MENU, self.onNewColumn, newColumnItem)
             
         elif 'table' in self.tree.GetItemText(self.tree.GetItemParent(self.tree.item)) : 
             logger.debug(self.tree.GetItemText(item))
-            editTableItem = menu.Append(wx.ID_ANY, "Edit table ")
+
+            editTableBmp = wx.MenuItem(menu, wx.ID_ANY, "Edit table")
+            editTableBmp.SetBitmap(wx.Bitmap(self.fileOperations.getImageBitmap(imageName="table_edit.png")))
+            editTableItem = menu.Append(editTableBmp) 
+            
+#             editTableItem = menu.Append(wx.ID_ANY, "Edit table ")
             renameTableItem = menu.Append(wx.ID_ANY, "Rename Table ")
             copyCreateTableItem = menu.Append(wx.ID_ANY, "Copy create table statement")
-                            
-            deleteTableItem = wx.MenuItem(menu, wx.ID_DELETE, "Delete \t Delete")
-            delBmp = wx.ArtProvider.GetBitmap(wx.ART_DELETE, wx.ART_MENU, (16, 16))
-            deleteTableItem.SetBitmap(delBmp)
-            delTableMenu = menu.Append(deleteTableItem)
-            
-            self.Bind(wx.EVT_MENU, self.onDeleteTable, delTableMenu)
+
+            deleteTableBmp = wx.MenuItem(menu, wx.ID_ANY, "&Delete table ")
+            deleteTableBmp.SetBitmap(wx.Bitmap(self.fileOperations.getImageBitmap(imageName="table_delete.png")))
+            deleteTableItem = menu.Append(deleteTableBmp)
+
+            self.Bind(wx.EVT_MENU, self.onDeleteTable, deleteTableItem)
             
             self.Bind(wx.EVT_MENU, self.onEditTable, editTableItem)
             self.Bind(wx.EVT_MENU, self.onRenameTable, renameTableItem)
@@ -444,10 +496,9 @@ class CreatingTreePanel(wx.Panel):
 
     def onRootNewConnection(self, event):
         logger.debug('onRootNewConnection')
-        CreateNewConncetionWixard().createWizard()
+        CreateNewConncetionWixard(self).createWizard()
         
         # Refresh tree.
-        self.onRootRefresh(event)
         
     def onCopyCreateTableStatement(self, event):
         logger.debug('onCopyCreateTableStatement')
@@ -462,7 +513,7 @@ class CreatingTreePanel(wx.Panel):
             logger.info('You entered: %s\n', dlg.GetValue())
             if dlg.GetValue() != self.tree.GetItemText(self.tree.GetSelection()):
                 logger.info('update table execute')
-                data = self.tree.GetPyData(self.tree.GetSelection())
+                data = self.tree.GetItemData(self.tree.GetSelection())
                 connectionName = data['connection_name']
                 databaseAbsolutePath = data['db_file_path']
                 if os.path.isfile(databaseAbsolutePath):     
@@ -474,32 +525,57 @@ class CreatingTreePanel(wx.Panel):
                     
 
                     '''
-                    pass
+                    logger.debug("TODO logic for rename column goes here.")
 #                     dbObjects = ManageSqliteDatabase(connectionName=connectionName , databaseAbsolutePath=databaseAbsolutePath).executeText(text) 
         dlg.Destroy()
 
+#     def onDeleteConnection(self, event):
+#         logger.debug('onDeleteConnection')
+#         logger.debug("TODO delete connection name")
+#         data = self.tree.GetItemData(self.tree.GetSelection())
+#         connectionName = data['connection_name']
+#         databaseAbsolutePath = data['db_file_path']
+#         if os.path.isfile(databaseAbsolutePath):
+#             sqlExecuter = SQLExecuter()
+#             text="DELETE FROM conns WHERE {} "
+#             sqlExecuter.executeText(text)
+        
     def onRenameTable(self, event):
         logger.debug('onRenameTable')
-        initialTableName = self.tree.GetItemText(self.tree.GetSelection())
-        dlg = wx.TextEntryDialog(self, 'Rename table ' + initialTableName, 'Rename table ' + initialTableName, 'Python')
+        oldTableName = initialTableName = self.tree.GetItemText(self.tree.GetSelection())
+        dlg = wx.TextEntryDialog(self, 'Rename table {} to'.format(initialTableName), 'Rename table {} '.format(initialTableName), 'Python')
         dlg.SetValue(self.tree.GetItemText(self.tree.GetSelection()))
 
         if dlg.ShowModal() == wx.ID_OK:
             logger.info('You entered: %s\n', dlg.GetValue())
             if dlg.GetValue() != self.tree.GetItemText(self.tree.GetSelection()):
                 logger.info('update table execute')
-                data = self.tree.GetPyData(self.tree.GetSelection())
+                newTableName = dlg.GetValue()
+                data = self.tree.GetItemData(self.tree.GetSelection())
                 connectionName = data['connection_name']
                 databaseAbsolutePath = data['db_file_path']
                 if os.path.isfile(databaseAbsolutePath):     
                     '''
                     First you rename the old table:
                     '''
-                    pass
-                
-#                     dbObjects = ManageSqliteDatabase(connectionName=connectionName , databaseAbsolutePath=databaseAbsolutePath).executeText(text) 
+                    logger.debug("TODO logic to rename table should go here.")
+#                     dropTableSql="DROP TABLE '{}'".format()
+                    alterTableSql = "ALTER TABLE '{}' RENAME TO {}".format(oldTableName, newTableName)
+                    db = ManageSqliteDatabase(connectionName=connectionName , databaseAbsolutePath=databaseAbsolutePath)
+                    try:
+                        db.executeText(alterTableSql)
+                    except Exception as e:
+                        self.consoleOutputLog(e)
+            self.recreateTree(event)
         dlg.Destroy()
         
+    def consoleOutputLog(self, exception=None):
+        now = datetime.datetime.now()
+        strftime = now.strftime("%Y-%m-%d %H:%M:%S")
+        newline = "\n"
+        if self.GetTopLevelParent()._mgr.GetPane("consoleOutput").window.text.Value.strip() == "":
+            newline = ""
+        self.GetTopLevelParent()._mgr.GetPane("consoleOutput").window.text.AppendText("{}{} {}".format(newline, strftime, exception))
     def onEditTable(self, event):
         logger.debug('onEditTable')
 
@@ -516,15 +592,18 @@ class CreatingTreePanel(wx.Panel):
         logger.debug('onConnectDb')
 #         item = self.tree.GetSelection() 
         try:
-            if self.tree.GetItemText(self.tree.GetSelection()) not in self.connDict:
-                self.connDict[self.tree.GetItemText(self.tree.GetSelection())] = True
+            if self.tree.GetItemText(self.tree.GetSelection()) not in self.connDict.keys():
                 selectedItemId = self.tree.GetSelection()
-                if self.getNodeOnOpenConnection(selectedItemId):
+                if self.getNodeOnOpenConnection(selectedItemId=selectedItemId):
         #         self.addNode(targetNode=, nodeLabel='got conncted',pydata=data, image=16)
                 # Todo change icon to enable
                         selectedItemText = self.tree.GetItemText(self.tree.GetSelection())
                         self.setAutoCompleteText(selectedItemText)
-                        self.openWorksheet()
+                        self.openWorksheet(sheetName="Worksheet")
+                self.connDict[self.tree.GetItemText(self.tree.GetSelection())] = {
+                    'isConnected':True,
+                    'data':self.tree.GetItemData(self.tree.GetSelection())
+                    }
         except Exception as e:
             logger.error(e, exc_info=True)
     
@@ -534,7 +613,7 @@ class CreatingTreePanel(wx.Panel):
         '''
         logger.debug(selectedItemText)
         if hasattr(self.GetTopLevelParent(), '_mgr'):
-            tb1 = self.GetTopLevelParent()._mgr.GetPane("tb1").window
+            tb1 = self.GetTopLevelParent()._mgr.GetPane("viewToolbar").window
             choice = self.GetTopLevelParent()._ctrl.GetChoices()
             textCtrl = self.GetTopLevelParent()._ctrl
             textCtrl.SetValue(selectedItemText)
@@ -553,16 +632,24 @@ class CreatingTreePanel(wx.Panel):
             # Todo change icon to dissable
     def onOpenSqlEditorTab(self, event):
         logger.debug('onOpenSqlEditorTab')
-        self.openWorksheet()
+        self.openWorksheet(sheetName="Worksheet")
 
-    def openWorksheet(self):
+    def openWorksheet(self, sheetName="Worksheet"):
         if hasattr(self.GetTopLevelParent(), '_mgr'):
             sqlExecutionTab = self.GetTopLevelParent()._mgr.GetPane("sqlExecution")
-            sqlExecutionTab.window.addTab("Worksheet")
-
+            if sqlExecutionTab.window:
+                sqlExecutionTab.window.addTab(name=sheetName)
+    
     def onProperties(self, event):
         logger.debug('onProperties')
         
+    def onImport(self, event=None):
+        logger.debug('onImport')
+        selectedItem = self.tree.GetSelection()
+        connectionName = self.tree.GetItemText(selectedItem)
+        frame = ImportingCsvExcelFrame(None, 'Import CSV Excel', connectionName)
+        frame.Show()
+        
     def onRefresh(self, event=None):
         logger.debug('onRefresh')
         '''
@@ -647,17 +734,23 @@ class CreatingTreePanel(wx.Panel):
         logger.debug('onNewView')
 
 #         tableFrame = CreateTableFrame(None, 'Table creation')
+    def onNewColumn(self, event):
+        logger.debug('onNewColumn')
+        logger.debug("TODO add a new column")
+
     def onNewIndex(self, event):
         logger.debug('onNewIndex')
+        logger.debug("TODO add a new Index")
 #         tableFrame = CreateTableFrame(None, 'Table creation')
         
-    def getNodeOnOpenConnection(self, selectedItemId):
+    def getNodeOnOpenConnection(self, selectedItemId=None, data=None):
         '''
         This method will return database node on open connection
         '''
         isSuccessfullyConnected = False
         logger.debug('getNodeOnOpenConnection')
-        data = self.tree.GetItemData(selectedItemId)
+        if selectedItemId:
+            data = self.tree.GetItemData(selectedItemId)
         connectionName = data['connection_name']
         databaseAbsolutePath = data['db_file_path']
         if os.path.isfile(databaseAbsolutePath):     
@@ -668,8 +761,11 @@ class CreatingTreePanel(wx.Panel):
                     logger.debug("k0 : %s, v0: %s", k0, v0)
                     data = dict()
                     data['depth'] = 2
+                    data['connection_name'] = connectionName
+                    data['db_file_path'] = databaseAbsolutePath
                     image = 2
                     nodeLabel = k0 + ' (' + str(len(v0)) + ')'
+                    
                     child0 = self.addNode(targetNode=selectedItemId, nodeLabel=nodeLabel, pydata=data, image=image) 
                     if 'table' == k0 :
                         # setting image for 'table'
@@ -686,6 +782,8 @@ class CreatingTreePanel(wx.Panel):
                             # Listing tables
                             data = dict()
                             data['depth'] = 3
+                            data['connection_name'] = connectionName
+                            data['db_file_path'] = databaseAbsolutePath
                             nodeLabel = k1 
                             if k0 == 'table':
                                 image = 4
@@ -695,6 +793,8 @@ class CreatingTreePanel(wx.Panel):
                             if k0 == 'table':
                                 data = dict()
                                 data['depth'] = 4
+                                data['connection_name'] = connectionName
+                                data['db_file_path'] = databaseAbsolutePath
                                 # setting  image for 'Columns', 'Unique Keys', 'Foreign Keys', 'References'
                                 image = 11
                                 
@@ -706,6 +806,8 @@ class CreatingTreePanel(wx.Panel):
                                 if k0 == 'table':
                                     data = dict()
                                     data['depth'] = 5
+                                    data['connection_name'] = connectionName
+                                    data['db_file_path'] = databaseAbsolutePath
     #                                  (cid integer, name text, type text, nn bit, dflt_value, pk bit)
                                     nodeLabel = v2[1]
                                     image = 18
@@ -722,15 +824,15 @@ class CreatingTreePanel(wx.Panel):
                                                 image = 18
                                                 break
                                     child2 = self.addNode(targetNode=child1_1, nodeLabel=nodeLabel, pydata=data, image=image) 
-#                                     logger.debug(v2)
         else:
             updateStatus = "Unable to connect '" + databaseAbsolutePath + ".' No such file. "
-            self.GetTopLevelParent()._mgr.GetPane("scriptOutput").window.text.AppendText("\n" + updateStatus)
+            self.consoleOutputLog(updateStatus)
             font = self.GetTopLevelParent().statusbar.GetFont() 
             font.SetWeight(wx.BOLD) 
             self.GetTopLevelParent().statusbar.SetFont(font) 
             self.GetTopLevelParent().statusbar.SetForegroundColour(wx.RED) 
             self.GetTopLevelParent().statusbar.SetStatusText(updateStatus, 1)
+            logger.error(updateStatus)
             
         return isSuccessfullyConnected
 
@@ -744,6 +846,7 @@ class DatabaseNavigationTree(ExpansionState, TreeCtrl):
         TreeCtrl.__init__(self, parent, style=wx.TR_DEFAULT_STYLE | 
                                wx.TR_HAS_VARIABLE_ROW_HEIGHT)
         self.BuildTreeImageList()
+        
 #         if USE_CUSTOMTREECTRL:
 #             self.SetSpacing(10)
 #             self.SetWindowStyle(self.GetWindowStyle() & ~wx.TR_LINES_AT_ROOT)
@@ -756,7 +859,7 @@ class DatabaseNavigationTree(ExpansionState, TreeCtrl):
 #                           'EVT_TREE_ITEM_COLLAPSING': self.OnItemCollapsing, 'EVT_TREE_ITEM_EXPANDED': self.OnItemExpanded,
 #                           'EVT_TREE_ITEM_EXPANDING': self.OnItemExpanding, 'EVT_TREE_ITEM_GETTOOLTIP': self.OnToolTip,
 #                           'EVT_TREE_ITEM_MENU': self.OnItemMenu, 'EVT_TREE_ITEM_RIGHT_CLICK': self.OnRightDown,
-                          'EVT_TREE_KEY_DOWN': self.OnKey,
+                            'EVT_TREE_KEY_DOWN': self.OnKey,
 #                           'EVT_TREE_SEL_CHANGED': self.OnSelChanged,
 #                           'EVT_TREE_SEL_CHANGING': self.OnSelChanging, "EVT_TREE_ITEM_HYPERLINK": self.OnHyperLink
                           }
@@ -774,7 +877,7 @@ class DatabaseNavigationTree(ExpansionState, TreeCtrl):
         keyname = keyMap.get(keycode, None)
                 
         if keycode == wx.WXK_BACK:
-            self.log.write("OnKeyDown: HAHAHAHA! I Vetoed Your Backspace! HAHAHAHA\n")
+            logger.debug("OnKeyDown: HAHAHAHA! I Vetoed Your Backspace! HAHAHAHA\n")
             return
 
         if keyname is None:
@@ -802,40 +905,31 @@ class DatabaseNavigationTree(ExpansionState, TreeCtrl):
 
     def BuildTreeImageList(self):
         logger.debug('BuildTreeImageList')
-        path = os.path.abspath(__file__)
-        tail = None
-#         head, tail = os.path.split(path)
-#         logger.debug('createAuiManager',head, tail )
-        try:
-            while tail != 'src':
-                path = os.path.abspath(os.path.join(path, '..',))
-                head, tail = os.path.split(path)
-        except Exception as e:
-            logger.error(e, exc_info=True)
-        path = os.path.abspath(os.path.join(path, "images"))
+        self.fileOperations = FileOperations()
         imgList = wx.ImageList(16, 16)
 
         # add the image for modified demos.
 
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "database.png"))))  # 0
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "database_category.png"))))  # 1
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "folder_view.png"))))  # 2
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "folder.png"))))  # 3
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "table.png"))))  # 4
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "view.png"))))  # 5
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "index.png"))))  # 6
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "column.png"))))  # 7 using to show integer column 
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "string.png"))))  # 8
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "key.png"))))  # 9
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "foreign_key_column.png"))))  # 10
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "columns.png"))))  # 11
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "unique_constraint.png"))))  # 12
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "reference.png"))))  # 13
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "datetime.png"))))  # 14
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "columns.png"))))  # 15
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "sqlite.png"))))  # 16
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "h2.png"))))  # 17 use to show h2 database icon
-        imgList.Add(wx.Bitmap(os.path.abspath(os.path.join(path, "textfield.png"))))  # 18 use to show [varchar, char, text data] type icon 
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="database.png"))  # 0
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="database_category.png"))  # 1
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="folder_view.png"))  # 2
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="folder.png"))  # 3
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="table.png"))  # 4
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="view.png"))  # 5
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="index.png"))  # 6
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="column.png"))  # 7 using to show integer column 
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="string.png"))  # 8
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="key.png"))  # 9
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="foreign_key_column.png"))  # 10
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="columns.png"))  # 11
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="unique_constraint.png"))  # 12
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="reference.png"))  # 13
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="datetime.png"))  # 14
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="columns.png"))  # 15
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="sqlite.png"))  # 16
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="h2.png"))  # 17 use to show h2 database icon
+        imgList.Add(self.fileOperations.getImageBitmap(imageName="textfield.png"))  # 18 use to show [varchar, char, text data] type icon 
+        
 #         imgList.Add(wx.Bitmap(path2))
 #         for png in _demoPngs:
 #             imgList.Add(catalog[png].GetBitmap())
@@ -870,6 +964,59 @@ class MainPanel(wx.Panel):
             return super(MainPanel, self).Thaw()
 
 
+class MyFileDropTarget(wx.FileDropTarget):
+
+    def __init__(self, dirwin):
+        wx.FileDropTarget.__init__(self)
+        self.dirwin = dirwin
+
+    def OnDropFiles(self, x, y, fileNams):
+        logger.debug("dropFiles {}".format(fileNams))
+        
+        try:
+            for fileAbsoluteName in fileNams:
+                if os.path.isdir(fileAbsoluteName):
+                    continue
+                logger.debug(fileAbsoluteName)
+                if self.isSQLite3(fileAbsoluteName):
+                    self.getConnectionName(filePath=fileAbsoluteName)
+                    sqlExecuter = SQLExecuter()
+                    obj = sqlExecuter.getObject()
+                    if len(obj[1]) == 0:
+                        sqlExecuter.createOpalTables()
+                    sqlExecuter.addNewConnectionRow(fileAbsoluteName, self.getConnectionName(filePath=fileAbsoluteName))
+                    self.dirwin.recreateTree()           
+        except Exception as ex:
+            logger.error(ex)
+              
+        return True
+
+    def getConnectionName(self, filePath=None):
+        head, tail = ntpath.split(filePath)
+        connectionName = "_".join(tail.split(sep=".")[:-1])
+        return connectionName
+    
+    def isSQLite3(self, fileName):
+        ''' this is to check a valid SQLite file dropped.
+        '''
+        from os.path import isfile, getsize
+    
+        if not isfile(fileName):
+            return False
+        if getsize(fileName) < 100:  # SQLite database file header is 100 bytes
+            return False
+    
+        with open(fileName, 'rb') as fd:
+            header = fd.read(100)
+    
+        return header[:16] == b'SQLite format 3\x00'
+#                 self.dirwin.addpath(filename)
+#                 if Globals.pref.open_project_setting_dlg:
+#                     wx.CallAfter(self.dirwin.OnSetProject)
+#             else:
+#                 Globals.mainframe.editctrl.new(filename)
+
+
 #---------------------------------------------------------------------------
 if __name__ == '__main__':
 #     treeImageLevel = dict()
@@ -884,6 +1031,6 @@ if __name__ == '__main__':
     try: 
         panel = CreatingTreePanel(frame, preferenceName='asfd')
     except Exception as ex:
-        print(ex)
+        logger.error(ex)
     frame.Show()
     app.MainLoop()
