@@ -1,6 +1,12 @@
 import wx
+import logging.config
+from src.view.constants import LOG_SETTINGS
 
 
+logging.config.dictConfig(LOG_SETTINGS)
+logger = logging.getLogger('extensive')
+################################################
+
 class ApplyResetButtonPanel(wx.Panel):
     
     def __init__(self, parent=None, *args, **kw):
@@ -20,6 +26,6 @@ class ApplyResetButtonPanel(wx.Panel):
         self.Bind(wx.EVT_BUTTON, self.onResetButton, id=wx.ID_ANY)
         self.Bind(wx.EVT_BUTTON, self.onApplyButton, id=wx.ID_ANY)
     def onResetButton(self, event):
-        print('reset button')
+        logger.debug('reset button')
     def onApplyButton(self, event):
-        print('apply button')
\ No newline at end of file
+        logger.debug('apply button')
\ No newline at end of file
