@@ -2,11 +2,15 @@ import wx
 from src.view.preference.CommandList import CommandKeyListCtrlPanel
 from src.view.preference.ApplyResetBtnPanel import ApplyResetButtonPanel
 
-from sys import exc_info
-import logging
 
+import logging.config
+from src.view.constants import LOG_SETTINGS
+
+
+logging.config.dictConfig(LOG_SETTINGS)
 logger = logging.getLogger('extensive')
 
+####################################################################
 
 class UserPanel(wx.Panel):
     def __init__(self, parent=None, *args, **kw):
@@ -81,11 +85,11 @@ class UserPanel(wx.Panel):
         self.pageSizeText.SetValue(str(event.GetPosition()))
     
     def EvtCheckBox(self, event):
-        print(self.isPaginationCheckBox)
-        print ('EvtCheckBox: %d\n' % event.IsChecked())
+        logger.debug(self.isPaginationCheckBox)
+        logger.debug('EvtCheckBox: %d\n' % event.IsChecked())
         cb = event.GetEventObject()
         if cb.Is3State():
-            print ("\t3StateValue: %s\n" % cb.Get3StateValue())
+            logger.debug("\t3StateValue: %s\n" % cb.Get3StateValue())
 
 class SearchPanel(wx.Panel):
     def __init__(self, parent=None, *args, **kw):
@@ -175,11 +179,11 @@ class SearchPanel(wx.Panel):
         self.pageSizeText.SetValue(str(event.GetPosition()))
     
     def EvtCheckBox(self, event):
-        print(self.isPaginationCheckBox)
-        print('EvtCheckBox: %d\n' % event.IsChecked())
+        logger.debug(self.isPaginationCheckBox)
+        logger.debug('EvtCheckBox: %d\n' % event.IsChecked())
         cb = event.GetEventObject()
         if cb.Is3State():
-            print ("\t3StateValue: %s\n" % cb.Get3StateValue())
+            logger.debug("\t3StateValue: %s\n" % cb.Get3StateValue())
 
 class WorkspacePanel(wx.Panel):
     def __init__(self, parent=None, *args, **kw):
@@ -358,10 +362,10 @@ class AppearancePanel(wx.Panel):
     def EvtComboBox(self, evt):
         cb = evt.GetEventObject()
         data = cb.GetClientData(evt.GetSelection())
-        print ('EvtComboBox: %s\nClientData: %s\n' % (evt.GetString(), data))
+        logger.debug('EvtComboBox: %s\nClientData: %s\n' % (evt.GetString(), data))
 
         if evt.GetString() == 'one':
-            print ("You follow directions well!\n\n")
+            logger.debug("You follow directions well!\n\n")
 
 class KeysPanel(wx.Panel):
     def __init__(self, parent=None, *args, **kw):
@@ -413,7 +417,7 @@ class KeysPanel(wx.Panel):
         print ('EvtComboBox: %s\nClientData: %s\n' % (evt.GetString(), data))
 
         if evt.GetString() == 'one':
-            print ("You follow directions well!\n\n")
+            logger.debug("You follow directions well!\n\n")
 
 class PreferencePanel(wx.Panel):
     def __init__(self, parent=None, *args, **kw):
