@@ -7,30 +7,24 @@ Created on 15-Dec-2016
 
 import wx
 import wx.stc as stc
-import keyword
 # from src.view.images import images
-import os
+import os, re
 # import string
 
 # from src.SqlBeautifier.sqlbeautifier import SqlBeautifierCommand
 # from src.view import SqliteKeywords
-from src.view.findAndReplace.FindAndReplacePanel import CreatingFindAndReplaceFrame
 from src.view.findAndReplace.GoToLinePanel import CreatingGoToLinePanel
 from src.sqlite_executer.ConnectExecuteSqlite import SQLExecuter, \
     ManageSqliteDatabase
-from datetime import date, datetime
 import time
 import logging
-# from sys import exc_info
 from sqlite3 import OperationalError
 import sqlparse
 from src.view import SqliteKeywords
+import datetime
 
 logger = logging.getLogger('extensive')
-# from src.format_sql.shortcuts import Beautify
-# from src.format_sql.shortcuts import format_sql
 
-#----------------------------------------------------------------------
 keylist = {
     'DOWN'  :stc.STC_KEY_DOWN,
     'UP'    :stc.STC_KEY_UP,
@@ -38,7 +32,6 @@ keylist = {
     'RIGHT' :stc.STC_KEY_RIGHT,
     'HOME'  :stc.STC_KEY_HOME,
     'END'   :stc.STC_KEY_END,
-    
     'PGUP'  :stc.STC_KEY_PRIOR,
     'PGDN'  :stc.STC_KEY_NEXT,
     'DEL'   :stc.STC_KEY_DELETE,
@@ -51,12 +44,9 @@ keylist = {
     '-'     :stc.STC_KEY_SUBTRACT,
     '/'     :stc.STC_KEY_DIVIDE,
 }
-demoText = """select * from book;
+demoText = """select * from table_name;
 """
 
-#----------------------------------------------------------------------
-print(wx.Platform) 
-
 if wx.Platform == '__WXMSW__':
     faces = { 'times': 'Consolas',
               'mono' : 'Consolas',
@@ -97,7 +87,6 @@ else:
               'size2': 10,
              }
 
-#----------------------------------------------------------------------
 
 
 class SqlStyleTextCtrl(stc.StyledTextCtrl):
@@ -107,6 +96,7 @@ class SqlStyleTextCtrl(stc.StyledTextCtrl):
                  pos=wx.DefaultPosition, size=wx.DefaultSize,
                  style=0):
         stc.StyledTextCtrl.__init__(self, parent, ID, pos, size, style)    
+        self.findData = wx.FindReplaceData()
         self.popmenu = None
         self.frame = None
         self.adviceList = list()
@@ -333,8 +323,8 @@ class SqlStyleTextCtrl(stc.StyledTextCtrl):
 
         elif event.ControlDown() and  key == 76:
             logger.debug('ctrl+L %s', self.GetSelectedText())
-            dlg = CreatingGoToLinePanel(self, -1, "Go to Line", size=(350, 200),
-                 style=wx.DEFAULT_DIALOG_STYLE,
+            dlg = CreatingGoToLinePanel(self, -1, title="Go to Line", size=(485, 192),
+                 style=wx.DEFAULT_DIALOG_STYLE, numberOfLines=self.LineCount
                  )
             dlg.CenterOnScreen()
             
@@ -345,7 +335,7 @@ class SqlStyleTextCtrl(stc.StyledTextCtrl):
                 lineNumber = dlg.lineNumberText.GetValue()
                 logger.debug("You pressed OK %s", lineNumber)
                 if lineNumber != '':
-                    self.GotoLine(int(lineNumber))
+                    self.GotoLine(int(lineNumber)-1)
                 
             else:
                 logger.debug("You pressed Cancel\n")
@@ -399,7 +389,7 @@ class SqlStyleTextCtrl(stc.StyledTextCtrl):
             logger.debug('ctrl+Alt+Down: duplicate line of code')
             selectedText = self.GetSelectedText()
             logger.debug(selectedText)
-            lineNo = self.GetCurrentLine()
+            # lineNo = self.GetCurrentLine()
             lineText, column = self.GetCurLine()
             if selectedText != None:
                 self.AddText(lineText)
@@ -412,8 +402,13 @@ class SqlStyleTextCtrl(stc.StyledTextCtrl):
             event.Skip()
         elif event.ControlDown() and  key == 70:
             logger.debug('ctrl+F: for find and relpace')
-            if self.frame == None:
-                self.frame = CreatingFindAndReplaceFrame(self, 'Find / Replace')
+            self.findData.SetFindString(self.GetSelectedText())
+        
+            self.finddlg = wx.FindReplaceDialog(self, self.findData, "Find & Replace", wx.FR_REPLACEDIALOG)
+            self.BindFindEvents(self.finddlg)
+            self.finddlg.Show(True)
+#             if self.frame == None:
+#                 self.frame = CreatingFindAndReplaceFrame(self, 'Find / Replace')
 #             self.copyClipboard(text=self.GetSelectedText())
             event.Skip()            
         elif not event.ControlDown() and event.AltDown() and key == 317:
@@ -470,6 +465,121 @@ class SqlStyleTextCtrl(stc.StyledTextCtrl):
         else:
             event.Skip()
             
+# =========================================================================
+    def BindFindEvents(self, win):
+        win.Bind(wx.EVT_FIND, self.OnFind)
+        win.Bind(wx.EVT_FIND_NEXT, self.OnFind)
+        win.Bind(wx.EVT_FIND_REPLACE, self.OnFind)
+        win.Bind(wx.EVT_FIND_REPLACE_ALL, self.OnFind)
+        win.Bind(wx.EVT_FIND_CLOSE, self.OnFindClose)        
+        
+    def OnFind(self, evt):
+        
+        end = self.GetLastPosition()
+        textstring = self.GetRange(0, end).lower()
+        findstring = evt.GetFindString().lower()
+        replaceTxt = ""
+        #print(repr(evt.GetFindString()), repr(self.findData.GetFindString()))
+        map = {
+            wx.wxEVT_COMMAND_FIND : "FIND",
+            wx.wxEVT_COMMAND_FIND_NEXT : "FIND_NEXT",
+            wx.wxEVT_COMMAND_FIND_REPLACE : "REPLACE",
+            wx.wxEVT_COMMAND_FIND_REPLACE_ALL : "REPLACE_ALL",
+            }
+
+        et = evt.GetEventType()
+
+        if et in map:
+            evtType = map[et]
+        else:
+            evtType = "**Unknown Event Type**"
+        if et in [wx.wxEVT_COMMAND_FIND_REPLACE]:
+            replaceTxt = "Replace text: %s" % evt.GetReplaceString()
+#             self.SetText(re.sub(findstring, evt.GetReplaceString(), self.GetText(), count=1, flags=re.I)) 
+            backward = not (evt.GetFlags() & wx.FR_DOWN)
+            if backward:
+                start = self.GetSelection()[0]
+                loc = textstring.rfind(findstring, 0, start)
+            else:
+                start = self.GetSelection()[1]
+                loc = textstring.find(findstring, start)
+            if loc == -1 and start != 0:
+                # string not found, start at beginning
+                if backward:
+                    start = end
+                    loc = textstring.rfind(findstring, 0, start)
+                else:
+                    start = 0
+                    loc = textstring.find(findstring, start)
+            if loc == -1:
+                dlg = wx.MessageDialog(self, 'Find String Not Found',
+                            'Find String Not Found ',
+                            wx.OK | wx.ICON_INFORMATION)
+                dlg.ShowModal()
+                dlg.Destroy()
+            if self.finddlg:
+                if loc == -1:
+                    self.finddlg.SetFocus()
+                    return
+    #             else:
+    #                 self.finddlg.Destroy()
+    #                 self.finddlg = None
+            self.ShowPosition(loc)
+            self.SetSelection(loc, loc + len(findstring))
+            self.SetText(self.GetText()[:loc]+evt.GetReplaceString()+self.GetText()[loc+len(findstring):])
+            #TODO : need to be workd
+        if et in [wx.wxEVT_COMMAND_FIND_REPLACE_ALL]:
+            # replaceTxt = "Replace text: %s" % evt.GetReplaceString()
+            self.SetText(re.sub(findstring, evt.GetReplaceString(), self.GetText(), flags=re.I)) 
+
+        if et in [wx.wxEVT_COMMAND_FIND, wx.wxEVT_COMMAND_FIND_NEXT]:
+            backward = not (evt.GetFlags() & wx.FR_DOWN)
+            if backward:
+                start = self.GetSelection()[0]
+                loc = textstring.rfind(findstring, 0, start)
+            else:
+                start = self.GetSelection()[1]
+                loc = textstring.find(findstring, start)
+            if loc == -1 and start != 0:
+                # string not found, start at beginning
+                if backward:
+                    start = end
+                    loc = textstring.rfind(findstring, 0, start)
+                else:
+                    start = 0
+                    loc = textstring.find(findstring, start)
+            if loc == -1:
+                dlg = wx.MessageDialog(self, 'Find String Not Found',
+                            'Find String Not Found ',
+                            wx.OK | wx.ICON_INFORMATION)
+                dlg.ShowModal()
+                dlg.Destroy()
+            if self.finddlg:
+                if loc == -1:
+                    self.finddlg.SetFocus()
+                    return
+    #             else:
+    #                 self.finddlg.Destroy()
+    #                 self.finddlg = None
+            self.ShowPosition(loc)
+            self.SetSelection(loc, loc + len(findstring))
+
+
+        logger.info("%s -- Find text: %s   Replace text: %s  Flags: %d  \n" %
+                       (evtType, evt.GetFindString(), replaceTxt, evt.GetFlags()))
+        
+
+#         findstring = self.finddata.GetFindString().lower()
+
+    
+        
+
+    def OnFindClose(self, evt):
+        logger.info("FindReplaceDialog closing...\n")
+        evt.GetDialog().Destroy()
+#         self.EnableButtons()
+# =========================================================================
+            
     def getAdvice(self):
         del self.adviceList[:]
         self.adviceList.append("select * from ")
@@ -613,7 +723,7 @@ class SqlStyleTextCtrl(stc.StyledTextCtrl):
         event.Skip()
 
     def onRightMouseDown(self, event):
-        other_menus = []
+        # other_menus = []
         logger.debug('OnPopUp self:%s event:%s', self, event)
         if self.popmenu:
             self.popmenu.Destroy()
@@ -815,9 +925,22 @@ class SqlStyleTextCtrl(stc.StyledTextCtrl):
                     manageSqliteDatabase = ManageSqliteDatabase(connectionName=selectedItemText, databaseAbsolutePath=dbFilePath)
                     sqlOutput = manageSqliteDatabase.executeText(sqlText)
                 except OperationalError as oe:
-                    self.GetTopLevelParent()._mgr.GetPane("scriptOutput").window.text.AppendText("\n" + str(oe))
+                    now = datetime.datetime.now()
+                    strftime = now.strftime("%Y-%m-%d %H:%M:%S")
+                    newline = "\n"
+                    if self.GetTopLevelParent()._mgr.GetPane("consoleOutput").window.text.Value.strip() == "":
+                        newline = ""
+                    self.GetTopLevelParent()._mgr.GetPane("consoleOutput").window.text.AppendText("{}{} {}".format(newline, strftime, oe))
+#                     self.GetTopLevelParent()._mgr.GetPane("consoleOutput").window.text.AppendText("\n" + str(oe))
                 except Exception as e:
                     logger.error(e, exc_info=True)
+                    now = datetime.datetime.now()
+                    strftime = now.strftime("%Y-%m-%d %H:%M:%S")
+                    newline = "\n"
+                    if self.GetTopLevelParent()._mgr.GetPane("consoleOutput").window.text.Value.strip() == "":
+                        newline = ""
+                    self.GetTopLevelParent()._mgr.GetPane("consoleOutput").window.text.AppendText("{}{} {}".format(newline, strftime, e))
+
                 endTime = time.time()
                 logger.debug('duration: %s', endTime - startTime)
                 duration = endTime - startTime
@@ -828,23 +951,35 @@ class SqlStyleTextCtrl(stc.StyledTextCtrl):
                 creatingWorksheetPanel.setResultData(data=sqlOutput)
                 resultListPanel = self.GetTopLevelParent()._mgr.GetPane("sqlExecution").window.GetChildren()[0].GetCurrentPage().Children[1].splitter.Children[1]
         #         if sqlOutput:
-                if resultListPanel._nb.GetCurrentPage():
+                if sqlOutput and resultListPanel._nb.GetCurrentPage():
+                    resultListPanel._nb.GetCurrentPage().bottomResultToolbar.SetStatusText('Count: {}'.format(len(sqlOutput)-1))
                     resultListPanel._nb.GetCurrentPage().resultPanel.addData(data=sqlOutput)
         except TypeError as te:
             logger.error(te, exc_info=True)
             if not dbFilePath:
                 error = 'Unable to connect. Please choose a database to execute Script.'
-                self.GetTopLevelParent()._mgr.GetPane("scriptOutput").window.text.AppendText("\n" + error)
+                now = datetime.datetime.now()
+                strftime = now.strftime("%Y-%m-%d %H:%M:%S")
+                newline = "\n"
+                if self.GetTopLevelParent()._mgr.GetPane("consoleOutput").window.text.Value.strip() == "":
+                    newline = ""
+                self.GetTopLevelParent()._mgr.GetPane("consoleOutput").window.text.AppendText("{}{} {}".format(newline, strftime, error))
         except Exception as e:
             logger.error(e, exc_info=True)
-            self.GetTopLevelParent()._mgr.GetPane("scriptOutput").window.text.AppendText("\n" + str(e))
+            now = datetime.datetime.now()
+            strftime = now.strftime("%Y-%m-%d %H:%M:%S")
+            newline = "\n"
+            if self.GetTopLevelParent()._mgr.GetPane("consoleOutput").window.text.Value.strip() == "":
+                newline = ""
+            self.GetTopLevelParent()._mgr.GetPane("consoleOutput").window.text.AppendText("{}{} {}".format(newline, strftime, e))
+
 #             print(e)
             error = str(e)
             
         self.refreshSqlLogUi()
 #         updateStatus="Unable to connect '"+dbFilePath +". "+error
-#         scriptOutputPanel = self.GetTopLevelParent()._mgr.GetPane("scriptOutput").window
-#         scriptOutputPanel.text.AppendText(error)
+#         consoleOutputPanel = self.GetTopLevelParent()._mgr.GetPane("consoleOutput").window
+#         consoleOutputPanel.text.AppendText(error)
 #             font = self.GetTopLevelParent().statusbar.GetFont() 
 #             font.SetWeight(wx.BOLD) 
 #             self.GetTopLevelParent().statusbar.SetFont(font) 
@@ -871,7 +1006,7 @@ class SqlStyleTextCtrl(stc.StyledTextCtrl):
         logger.debug('updateSqlLog : %s', sqlText)
         sqlExecuter = SQLExecuter(database='_opal.sqlite')
         table = 'sql_log'
-        rows = [{'id':None, 'sql':str(sqlText), 'connection_name':connectionName, 'created_time':datetime.now(), 'executed':'1', 'duration':duration}]
+        rows = [{'id':None, 'sql':str(sqlText), 'connection_name':connectionName, 'created_time':datetime.datetime.now(), 'executed':'1', 'duration':duration}]
         sqlExecuter.sqlite_insert(table, rows)
         
     def refreshSqlLogUi(self):
@@ -923,7 +1058,7 @@ class CreatingEditorPanel(wx.Panel):
         self.parent = parent
         
         vBox = wx.BoxSizer(wx.VERTICAL)
-
+        self.findData = wx.FindReplaceData()
         ####################################################################
         self.sstc = SqlStyleTextCtrl(self, -1)
         self.sstc.initKeyShortCut()
@@ -943,7 +1078,6 @@ class CreatingEditorPanel(wx.Panel):
         self.SetSizer(sizer)
 
 
-#---------------------------------------------------------------------------
 if __name__ == '__main__':
     app = wx.App(False)
     frame = wx.Frame(None)
